@@ -6,7 +6,7 @@ class Venue(models.Model):
     venue_name = models.TextField(max_length=80, primary_key=True)
     venue_path = models.TextField(max_length=255)
 
-    def __init__(self):
+    def __init__(self, venue_name, venue_path=os.getcwd()):
         self.venue_root = os.path.abspath(os.path.join(self.venue_path, self.venue_name))
         self.uwsgi_ini = os.path.join(self.venue_root, 'backstage-%s-uwsgi.ini' % (self.venue_name))
         self.acts_dir = os.path.join(self.venue_root, 'acts')
